plotMosaic <- function(d, m, pch=20, lcol="blue", ...) {
  n.patches <- nrow(d)
  x <- seq(0, 1, length=n.patches)
  n <- rowSums(d[1:3])
  p <- with(d, AA + Aa/2)/n
  plot(x, p, pch=pch, ...)

  usr <- par("usr")
  dx <- 1/(2*(n.patches - 1))
  sx <- c(usr[1], rep(c(-dx, x[m] + dx, 1+dx), each=2), usr[2])
  sy <- rep(step.heights(d, m), each=2)
  lines(sx, sy, col=lcol)
}

plot.mosaic <- function(x, nsteps=NULL, ...) {
  if ( is.null(nsteps) )
    nsteps <- length(x)
  plotMosaic(attr(x, "data"), x[[nsteps]]$best.model, ...)
}

## Cut the data at a series of points, and apply some function to each
## group.
##
## This is the workhorse function; given a vector of values 'x', and a
## vector of indices 'at', cut 'x', to produce a list:
##   x[1..at[1]], x[(at[1]+1)..at[2]], ..., x[(at[n]+1)..length(x)]
## Return the result of some function 'f' applied to each of these
## sublists:
##   f(x[1..at[1]]),
##   f(x[(at[1]+1)..at[2]]),
##   ...,
##   f(x[(at[n]+1)..length(x)])
f.at <- function(x, at, f) {
  from <- c(0, at) + 1
  to   <- c(at, length(x))
  lapply(seq_along(from), function(i) f(x[from[i]:to[i]]))
}

## return the step heights of model m (this is a modification of your
## method and is where the time is spent...)
step.heights <- function(d, m) {
  N <- rowSums(d)
  freq.p <- d/N
  p <- freq.p[,1] + freq.p[,2]/2
  f <- 1 - freq.p[,2]/(2 * p * (1 - p))
  f[is.nan(f)] <- 1
  from <- c(0, m) + 1
  to   <- c(m, length(d[,1]))
  steps <- lapply(seq_along(from), function(i) from[i]:to[i])
  heights <- sapply(steps, function(k) binFunc(d[k,], f[k], p[k]))[2,]
  c(0, heights, 1)
}

## sum the steps of a dataset, returning a vector of mean step sums
mosaicity <- function(d, m) {
  z <- step.heights(d, m)
  (sum(abs(diff(z))) - 1)/2
}

## nice little pfd plotting function
pdf.f <- function(f, file, ...) {
  cat(sprintf("Writing %s\n", file))
  pdf(file, ...)
  on.exit(dev.off())
  f()
}
