\name{fit.mosaic}
\alias{fit.mosaic}

\title{Fit a Mosaic Model Using Maximum Likelihood}

\description{This function fits a step-wise model to data from a one
  dimensional hybrid zone.}

\usage{
fit.mosaic(data, sig.level, N=50, ngens=100, s=5, p.mutate=0.1, p.sex=1,
           p.rec=0.25, verbose=TRUE)
}

\arguments{
  \item{data}{a data frame where columns represent genotype frequencies
    and rows correspond to patches in a one dimensional hybrid zone
    dataset. See \code{\link{hybrid.zone}} for a sample dataset and more
    information}
  \item{sig.level}{desired significance level for the number of steps
    fit by the model}
  \item{N}{the 'population size' used in the genetic algorithm (a larger
    population will typically result in a more accurate best fit model,
    but also will increase the calculation time)}
  \item{ngens}{number of generations to run the genetic algorithm for 
    (more generations will typically result in a more accurate best fit 
    model, but also will increase the calculation time)}
  \item{s}{strength of selection used in the genetic algorithm}
  \item{p.mutate}{mutation rate (e.g., probability of moving the
    location of a step in a model during reproduction in the genetic
    algorithm} 
  \item{p.sex}{probability of sexually recombining two models to create 
    permuted offspring models in the genetic algorithm}
  \item{p.rec}{a real number between 0 and 0.5 which denotes the
    probability that recombination occurs between two model step
    locations in a sexual event in the genetic algorithm} 
  \item{verbose}{a logical value indicating the level of output as the
    algorithm runs}
}

% \details{
%   I would put a more complete description of 'data' here.  What are rows
%   and columns?
% }

\seealso{\code{\link{plotMosaic}} for plotting fitted models,
  \code{\link{mosaicity}} for summing step heights of models,
  \code{\link{hybrid.zone}} for a sample dataset, and
  \code{\link{make.mosaic.logLik}} for computing likelihoods.}

\examples{
\dontrun{
data(hybrid.zone)
res <- fit.mosaic(hybrid.zone, 0.05)
plot(res)
mosaicity(hybrid.zone, best.model)
}
}

\references{
    M'Gonigle, L.K., FitzJohn, R.G. 2010. Assortative Mating and Spatial
    Structure in Hybrid Zones. Evolution: 64: 444--445.
}
\keyword{model}
\author{LKM & RGF}